@@ -23,6 +23,15 @@ class styleSheet:
 				sortedDict[rule.selectors] = [(rule.property,rule.value)]
 		return sortedDict
 
+	def getRules(self):
+		""" returns the list of all the rules"""
+		return self.rules
+
+	def getQuerys(self):
+		""" returns the list of all the querys """
+		return self.medias
+
+
 	def addQuery(self,query):
 		""" to add a media query """
 		self.medias.append(query)
@@ -77,9 +86,12 @@ class mediaQuery(styleSheet):
 			r+='and ('+condition+') '
 
 		r+='{\n'
-		r+=styleSheet.render(self)
+		rend = styleSheet.render(self)
+		rend = '\n'.join(['\t'+e for e in rend.split('\n')])
+		rend = rend[:-1]
+		r+=rend
 		r+='}'
-
+		# print(rend)
 		return r
 
 
@@ -144,9 +156,12 @@ def createBatch(selectors,declarations):
 if __name__=='__main__':
 	s=styleSheet()
 	
-
+	m1 = mediaQuery('only','screen','minwidth:600ppx')
 	b1 = createBatch(('a','div:hover'),[('color','green'),('background-color','blue')])
-	s.addList(b1)
+	print(b1)
+	m1.addList(b1)
+
+	s.addQuery(m1)
 
 
 	print(s.render())
