@@ -129,42 +129,7 @@ class form(tag):
 			return labelTag,inputTag
 
 
-#############
-# Fonctions #
-#############
 
-def createEmptyPage(title=None,header = False):
-	"""create an empty page with a head and a body
-	optinal : title,header
-	returns the root, the head and the body and present : header and/or footer"""
-	root = tag('html')
-	head = tag('head')
-	body = tag('body')
-	root.add(head)
-	root.add(body)
-	r = [root,head,body]
-	if title:
-		titleTag = tag('title')
-		titleTag.add(title)
-		head.add(titleTag)
-	if header:
-		headerTag = tag('header')
-		body.add(headerTag)
-		r.append(headerTag)
-
-	return tuple(r)
-
-
-def paragraph(text):
-	"""create a paragraphe with text
-	changing \\n by <br> tags"""
-	r = tag('p')
-	pliste = text.split('\n')
-	for e in pliste[:-1]:
-		r.add(e)
-		r.add(tag('br'))
-	r.add(pliste[-1])
-	return r
 
 ##################
 # body for tests #
